@@ -2,7 +2,7 @@ package Power::Outlet;
 use strict;
 use warnings;
 
-our $VERSION='0.17';
+our $VERSION='0.19';
 
 =head1 NAME
 
@@ -46,13 +46,13 @@ I hope to integrate with services like IFTTT (ifttt.com).  I would appreciate co
 Integration with Home Assistant L<https://home-assistant.io/> should be as easy as configuring a Command Line Switch. 
 
   switch:
-    platform: command_line
-    switches:
-      ibootbar-1:
-        command_on: "/usr/bin/power-outlet iBootBar ON host mybar outlet 1"
-        command_off: "/usr/bin/power-outlet iBootBar OFF host mybar outlet 1"
-        command_state: "/usr/bin/power-outlet iBootBar QUERY host mybar outlet 1 | /bin/grep -q ON"
-        friendly_name: iBootBar Outlet 1
+    - platform: command_line
+      switches:
+        ibootbar_1:
+          command_on: /usr/bin/power-outlet iBootBar ON host mybar.local outlet 1
+          command_off: /usr/bin/power-outlet iBootBar OFF host mybar.local outlet 1
+          command_state: /usr/bin/power-outlet iBootBar QUERY host mybar.local outlet 1 | /bin/grep -q ON
+          friendly_name: My iBootBar Outlet 1
 
 See L<https://home-assistant.io/components/switch.command_line/>
 
