@@ -4,7 +4,7 @@ use warnings;
 use Time::HiRes qw{sleep};
 use base qw{Package::New};
 
-our $VERSION='0.15';
+our $VERSION='0.16';
 our $STATE="OFF";
 
 =head1 NAME
@@ -55,7 +55,7 @@ sub on {return $STATE="ON"};
 
 The off method must be overridden in the sub class.
 
-  $outlet->on;   #turns the outlet off reguardless of current state and returns OFF.
+  $outlet->off;   #turns the outlet off reguardless of current state and returns OFF.
 
 Note: This should cancel any non-blocking cycle requests
 
